==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/fi/mail.php <==
<?php

return array(
    'a_user_canceled' => 'Käyttäjä on peruuttanut nimikkeen pyynnön sivustolla',
    'a_user_requested' => 'Käyttäjä on pyytänyt nimikettä sivustolla',
    'accessory_name' => 'Oheistarvikkeen nimi:',
    'additional_notes' => 'Muistiinpanot:',
    'admin_has_created' => 'Järjestelmänvalvoja on luonut tilin sinulle :web verkkosivustolle.',
    'asset' => 'Laite:',
    'asset_name' => 'Laitteen nimi:',
    'asset_requested' => 'Pyydetty laite',
    'asset_tag' => 'Laitetunniste:',
    'assigned_to' => 'Osoitettu',
    'best_regards' => 'Parhain terveisin,',
    'canceled' => 'Peruutettu:',
    'checkin_date' => 'Palautuspäivä:',
    'checkout_date' => 'Luovutuspäivä:',
    'click_to_confirm' => 'Vahvista tilisi klikkaamalla seuraavaa linkkiä :web:',
    'click_on_the_link_accessory' => 'Klikkaa alla olevaa linkkiä vahvistaaksesi, että olet vastaanottanut oheistarvikeen.',
    'click_on_the_link_asset' => 'Klikkaa alla olevaa linkkiä vahvistaaksesi, että olet vastaanottanut laitteen.',
    'Confirm_Asset_Checkin' => 'Laitteen palautuksen vahvistus',
    'Confirm_Accessory_Checkin' => 'Oheistarvikkeen palautuksen vahvistus',
    'Confirm_accessory_delivery' => 'Oheistarvikkeen toimittamisen vahvistaminen',
    'Confirm_license_delivery' => 'Lisenssin toimituksen vahvistus',
    'Confirm_asset_delivery' => 'Laitteen toimituksen vahvistus',
    'Confirm_consumable_delivery' => 'Kulutustarvikkeen toimituksen vahvistus',
    'current_QTY' => 'Nykyinen määrä',
    'Days' => 'Päivää',
    'days' => 'Päiviä',
    'expecting_checkin_date' => 'Odotettu palautuspäivä:',
    'expires' => 'Vanhenee',
    'Expiring_Assets_Report' => 'Raportti vanhentuvista laitteista.',
    'Expiring_Licenses_Report' => 'Raportti vanhenevista lisensseistä.',
    'hello' => 'Hei',
    'hi' => 'Moi',
    'i_have_read' => 'Olen lukenut ja hyväksynyt käyttöehdot ja olen saanut tämän kohteen.',
    'item' => 'Nimike:',
    'Item_Request_Canceled' => 'Nimikkeen pyyntö peruutettu',
    'Item_Requested' => 'Pyydetty nimike',
    'link_to_update_password' => 'Napsauta seuraavaa linkkiä päivittääksesi :web salasanasi:',
    'login_first_admin' => 'Kirjaudu sisään uuteen Snipe-IT asennukseen käyttäen alla olevia tunnistetietoja:',
    'login' => 'Kirjaudu sisään:',
    'Low_Inventory_Report' => 'Alhainen määrä raportti',
    'min_QTY' => 'Minimi määrä',
    'name' => 'Nimi',
    'new_item_checked' => 'Uusi nimike on luovutettu sinulle, yksityiskohdat ovat alla.',
    'password' => 'Salasana:',
    'password_reset' => 'Salasanan nollaus',

    'read_the_terms' => 'Lue alla olevat käyttöehdot.',
    'read_the_terms_and_click' => 'Lue käyttöehdot ja klikkaa alla olevaa linkkiä vahvistaaksesi, että olet lukenut käyttöehdot ja että olet hyväksynyt käyttöehdot.',
    'requested' => 'Pyydetty:',
    'reset_link' => 'Salasanasi resetointi-linkki',
    'reset_password' => 'Palauta salasanasi napsauttamalla tätä:',
    'serial' => 'Sarjanumero',
    'supplier' => 'Toimittaja',
    'tag' => 'Tunniste',
    'test_email' => 'Testi sähköposti Snipe-IT: stä',
    'test_mail_text' => 'Tämä on testi Snipe-IT Asset Management -järjestelmästä. Jos saat tämän, sähköposti toimii :)',
    'the_following_item' => 'Seuraava kohde on palautettu: ',
    'low_inventory_alert' => ':count nimikkeen saldomäärä on alle minimirajan tai kohta alhainen.|:count nimikkeen saldomäärä on alle minimirajan tai kohta alhainen.',
    'assets_warrantee_alert' => ':count laitteen takuu päättyy :threshold päivän sisällä.|:count laitteen takuu päättyy :threshold päivän sisällä.',
    'license_expiring_alert' => ':count lisenssiä vanhenee :threshold päivän sisällä.|:count lisenssiä vanhenee :threshold päivän sisällä.',
    'to_reset' => 'Voit palauttaa :web salasanasi täyttämällä tämän lomakkeen:',
    'type' => 'Tyyppi',
    'upcoming-audits' => 'Seuraavien :count laitteiden tarkistus on tulossa :threshold päivän aikana .|Seuraavien :count laitteiden tarkistus on tulossa :threshold päivän aikana.',
    'user' => 'Käyttäjä',
    'username' => 'Käyttäjätunnus',
    'welcome' => 'Tervetuloa :name',
    'welcome_to' => 'Tervetuloa :web!',
    'your_credentials' => 'Snipe-IT - kirjautumistietosi',
    'Accessory_Checkin_Notification' => 'Oheistarvike palautettu',
    'Asset_Checkin_Notification' => 'Laite palautettu',
    'License_Checkin_Notification' => 'Lisenssi palautettu',
    'Expected_Checkin_Report' => 'Odotettujen palautuspäivien raportti',
    'Expected_Checkin_Notification' => 'Muistutus: :name palautuspäivä lähestyy',
    'Expected_Checkin_Date' => 'Sinulle luovutettu laite on määrä palauttaa takaisin :date',
    'your_assets' => 'Omat laitteesi'
);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/fi/mail.php <==
<?php

return [
    'a_user_canceled' => 'Käyttäjä on peruuttanut nimikkeen pyynnön sivustolla',
    'a_user_requested' => 'Käyttäjä on pyytänyt nimikettä sivustolla',
    'accessory_name' => 'Oheistarvikkeen nimi:',
    'additional_notes' => 'Muistiinpanot:',
    'admin_has_created' => 'Järjestelmänvalvoja on luonut tilin sinulle :web verkkosivustolle.',
    'asset' => 'Laite:',
    'asset_name' => 'Laitteen nimi:',
    'asset_requested' => 'Pyydetty laite',
    'asset_tag' => 'Laitetunniste',
    'assigned_to' => 'Osoitettu',
    'best_regards' => 'Parhain terveisin,',
    'canceled' => 'Peruutettu:',
    'checkin_date' => 'Palautuspäivä:',
    'checkout_date' => 'Luovutuspäivä:',
    'click_to_confirm' => 'Vahvista tilisi klikkaamalla seuraavaa linkkiä :web:',
    'click_on_the_link_accessory' => 'Klikkaa alla olevaa linkkiä vahvistaaksesi, että olet vastaanottanut oheistarvikeen.',
    'click_on_the_link_asset' => 'Klikkaa alla olevaa linkkiä vahvistaaksesi, että olet vastaanottanut laitteen.',
    'Confirm_Asset_Checkin' => 'Laitteen palautuksen vahvistus',
    'Confirm_Accessory_Checkin' => 'Oheistarvikkeen palautuksen vahvistus',
    'Confirm_accessory_delivery' => 'Oheistarvikkeen toimittamisen vahvistaminen',
    'Confirm_license_delivery' => 'Lisenssin toimituksen vahvistus',
    'Confirm_asset_delivery' => 'Laitteen toimituksen vahvistus',
    'Confirm_consumable_delivery' => 'Kulutustarvikkeen toimituksen vahvistus',
    'current_QTY' => 'Nykyinen määrä',
    'Days' => 'Päivää',
    'days' => 'Päiviä',
    'expecting_checkin_date' => 'Odotettu palautuspäivä:',
    'expires' => 'Vanhenee',
    'Expiring_Assets_Report' => 'Raportti vanhentuvista laitteista.',
    'Expiring_Licenses_Report' => 'Raportti vanhenevista lisensseistä.',
    'hello' => 'Hei',
    'hi' => 'Moi',
    'i_have_read' => 'Olen lukenut ja hyväksynyt käyttöehdot ja olen saanut tämän kohteen.',
    'item' => 'Nimike:',
    'Item_Request_Canceled' => 'Nimikkeen pyyntö peruutettu',
    'Item_Requested' => 'Pyydetty nimike',
    'link_to_update_password' => 'Napsauta seuraavaa linkkiä päivittääksesi :web salasanasi:',
    'login_first_admin' => 'Kirjaudu sisään uuteen Snipe-IT asennukseen käyttäen alla olevia tunnistetietoja:',
    'login' => 'Kirjaudu sisään:',
    'Low_Inventory_Report' => 'Alhainen määrä raportti',
    'min_QTY' => 'Minimi määrä',
    'name' => 'Nimi',
    'new_item_checked' => 'Uusi nimike on luovutettu sinulle, yksityiskohdat ovat alla.',
    'password' => 'Salasana:',
    'password_reset' => 'Salasanan nollaus',

    'read_the_terms' => 'Lue alla olevat käyttöehdot.',
    'read_the_terms_and_click' => 'Lue käyttöehdot ja klikkaa alla olevaa linkkiä vahvistaaksesi, että olet lukenut käyttöehdot ja että olet hyväksynyt käyttöehdot.',
    'requested' => 'Pyydetty:',
    'reset_link' => 'Salasanasi resetointi-linkki',
    'reset_password' => 'Palauta salasanasi napsauttamalla tätä:',
    'serial' => 'Sarjanumero',
    'supplier' => 'Toimittaja',
    'tag' => 'Tunniste',
    'test_email' => 'Testi sähköposti Snipe-IT: stä',
    'test_mail_text' => 'Tämä on testi Snipe-IT Asset Management -järjestelmästä. Jos saat tämän, sähköposti toimii :)',
    'the_following_item' => 'Seuraava kohde on palautettu: ',
    'low_inventory_alert' => ':count nimikkeen saldomäärä on alle minimirajan tai kohta alhainen.|:count nimikkeen saldomäärä on alle minimirajan tai kohta alhainen.',
    'assets_warrantee_alert' => 'There is :count asset with a warranty expiring in the next :threshold days.|There are :count assets with warranties expiring in the next :threshold days.',
    'license_expiring_alert' => ':count lisenssiä vanhenee :threshold päivän sisällä.|:count lisenssiä vanhenee :threshold päivän sisällä.',
    'to_reset' => 'Voit palauttaa :web salasanasi täyttämällä tämän lomakkeen:',
    'type' => 'Tyyppi',
    'upcoming-audits' => 'Seuraavien :count laitteiden tarkistus on tulossa :threshold päivän aikana .|Seuraavien :count laitteiden tarkistus on tulossa :threshold päivän aikana.',
    'user' => 'Käyttäjä',
    'username' => 'Käyttäjätunnus',
    'welcome' => 'Tervetuloa :name',
    'welcome_to' => 'Tervetuloa :web!',
    'your_credentials' => 'Snipe-IT - kirjautumistietosi',
    'Accessory_Checkin_Notification' => 'Oheistarvike palautettu',
    'Asset_Checkin_Notification' => 'Laite palautettu',
    'License_Checkin_Notification' => 'Lisenssi palautettu',
    'Expected_Checkin_Report' => 'Odotettujen palautuspäivien raportti',
    'Expected_Checkin_Notification' => 'Muistutus: :name palautuspäivä lähestyy',
    'Expected_Checkin_Date' => 'Sinulle luovutettu laite on määrä palauttaa takaisin :date',
    'your_assets' => 'Omat laitteesi',
];
